Module: FedgerAPI::Client::News
- Included in:
- FedgerAPI::Client
- Defined in:
- lib/fedger_api/client/news.rb
Overview
News
Instance Method Summary collapse
-
#latest_fundings ⇒ Object
Returns a collection of the most recent fundings covered.
Instance Method Details
#latest_fundings ⇒ Object
Returns a collection of the most recent fundings covered.
6 7 8 |
# File 'lib/fedger_api/client/news.rb', line 6 def latest_fundings news_provider('/fundings') end |